@@ -4,6 +4,7 @@ from pathlib import Path
 from typing import Any, Optional
 
 from mashumaro import DataClassDictMixin
+from py_app_dev.core.config import merge_configs
 
 from yanga.cmake.artifacts_locator import BuildArtifact, CMakeArtifactsLocator
 from yanga.cmake.coverage import CoverageArtifactsLocator, CoverageRelevantFile
@@ -11,16 +12,12 @@ from yanga.domain.artifacts import ProjectArtifactsLocator
 from yanga.domain.component_analyzer import ComponentAnalyzer
 from yanga.domain.components import Component
 from yanga.domain.config import MockingConfiguration
-from yanga.domain.execution_context import (
-    ExecutionContext,
-    UserRequest,
-    UserRequestScope,
-    UserRequestTarget,
-)
+from yanga.domain.execution_context import ExecutionContext, UserRequest, UserRequestScope, UserRequestTarget
 from yanga.domain.reports import ReportRelevantFiles, ReportRelevantFileType
 
 from .cmake_backend import (
     CMakeAddExecutable,
+    CMakeAddLibrary,
     CMakeAddSubdirectory,
     CMakeCommand,
     CMakeComment,
@@ -29,11 +26,11 @@ from .cmake_backend import (
     CMakeElement,
     CMakeEmptyLine,
     CMakeIncludeDirectories,
-    CMakeObjectLibrary,
     CMakePath,
     CMakeSetTargetProperties,
     CMakeTargetIncludeDirectories,
     CMakeVariable,
+    IncludeScope,
 )
 from .generator import CMakeGenerator
 
@@ -133,6 +130,7 @@ class CMakeMockupCreator:
                     ],
                 )
             ],
+            command_expand_lists=True,
         )
         elements.append(custom_command)
         # Custom command to run clanguru and generate the mockup sources
@@ -213,7 +211,7 @@ class GTestComponentCMakeGenerator:
         productive_sources = component_analyzer.collect_sources()
 
         # Always create the component productive sources object library
-        component_sources_object_library = CMakeObjectLibrary(
+        component_sources_object_library = CMakeAddLibrary(
             name=gtest_cmake_component.partial_link_name,
             files=productive_sources,
             compile_options=[
@@ -225,9 +223,9 @@ class GTestComponentCMakeGenerator:
         # Add include directories specific to this component plus the component build dir to find generated mockup sources
         include_dirs: list[CMakePath] = [component_build_dir, *gtest_cmake_component.get_include_directories()]
         if include_dirs and not component_generator_config.use_global_includes:
-            # Determine visibility: use PRIVATE for libraries with sources, INTERFACE for header-only
-            visibility = "INTERFACE" if not productive_sources else "PRIVATE"
-            target_includes = CMakeTargetIncludeDirectories(component_sources_object_library.target_name, include_dirs, visibility)
+            # Determine include scope: use PRIVATE for libraries with sources, INTERFACE for header-only
+            scope = IncludeScope.INTERFACE if not productive_sources else IncludeScope.PRIVATE
+            target_includes = CMakeTargetIncludeDirectories(component_sources_object_library.target_name, include_dirs, scope)
             elements.append(target_includes)
 
         mockup_generator = None
@@ -255,8 +253,8 @@ class GTestComponentCMakeGenerator:
             # Add component-specific include directories when global includes are disabled
             if include_dirs and not component_generator_config.use_global_includes:
                 # Determine visibility: use PRIVATE for executables with sources, INTERFACE for header-only
-                visibility = "INTERFACE" if not all_sources else "PRIVATE"
-                target_includes = CMakeTargetIncludeDirectories(test_executable.name, include_dirs, visibility)
+                scope = IncludeScope.INTERFACE if not all_sources else IncludeScope.PRIVATE
+                target_includes = CMakeTargetIncludeDirectories(test_executable.name, include_dirs, scope)
                 elements.append(target_includes)
 
             # Create the custom target to execute the tests
@@ -343,10 +341,7 @@ class GTestComponentCMakeGenerator:
             if not result.mocking:
                 result.mocking = component.testing.mocking
             else:
-                if component.testing.mocking.enabled is not None:
-                    result.mocking.enabled = component.testing.mocking.enabled
-                if component.testing.mocking.exclude_symbol_patterns:
-                    result.mocking.exclude_symbol_patterns = component.testing.mocking.exclude_symbol_patterns
+                result.mocking = merge_configs(result.mocking, component.testing.mocking)
         return result
 
     def add_executable(self, component_name: str, sources: list[Path], component_object_library: str) -> CMakeAddExecutable:
@@ -378,9 +373,9 @@ class GTestComponentCMakeGenerator:
         outputs = [component_build_dir.joinpath(f"{component_name}_junit.xml")]
         return CMakeCustomCommand(
             "Run the test executable, generate JUnit report and return success independent of the test result",
-            outputs,
-            [component_executable_name],
-            [command],
+            outputs=outputs,
+            depends=[component_executable_name],
+            commands=[command],
         )
 
     def create_coverage_report(
